C*******************************************************************    
C                                                                       
C SUBROUTINE DRAGON                                                     
C                                                                       
C PURPOSE:  TO CALCULATE DRAG BASED ON 1ST GUESS SEA LEVEL WINDS, 1ST   
C           GUESS GROUND TEMPERATURE, AND ANALYZED SEA LEVEL TEMP.      
C                                                                       
C INPUT/OUTPUT:  PHISA  - MODEL 'PHIS'   (TOPOGRAPHY*GRAVITY)           
C                ZLWFLAG- LAND/WATER FLAG (0=LAND, 1=WATER)             
C                USLMF  - 1ST GUESS SEA LEVEL U                         
C                VSLMF  - 1ST GUESS SEA LEVEL V                         
C                TSURF  - ANALYZED SEA LEVEL TEMPERATURE                
C                GT     - 1ST GUESS GROUND TEMPERATURE                  
C                                                                       
C ON OUTPUT :    DRAG :  CALCULATED DRAGS                               
C              IWATER :  INTEGER ARRAY WHICH SIGNALS IF GRID POINT IS   
C                        OVER LAND OR OCEAN (0=LAND, 1=WATER)           
C                                                                       
C LOCAL VARIABLES:  DELT - DIFFERENCE BETWEEN GROUND AND SEA LEVEL TEMP 
C                   WIND - MAGNITUDE OF SEA LEVEL WIND VELOCITY         
C                   HOLD - WORK ARRAY                                   
C                   HOLDBIT- WORK BIT ARRAY                             
C                   CD   - DRAG COEFFICIENT                             
C                   DRG  - INTERACTION COEFFICIENT                      
C                                                                       
C NOTES:   1) THE DRAG IS CALCULATED IN THE SAME MANNER AS THAT OF      
C             THE MODEL. SEE MODEL DOCUMENTATION FOR DETAILS.           
C                                                                       
C         *2) DRAGS ARE CALCULATED OVER OCEANS ONLY FOR THIS ANALYSIS   
C             SINCE DRAGS COMPUTED OVER LAND ARE UNRELIABLE. NOTE THAT  
C             THIS IMPLIES THAT 'DELT' IS A DIFFERENCE BETWEEN GROUND   
C             AND SEA LEVEL TEMPERATURES WHEN OVER OCEANS.              
C                                                                       
C********************************************************************   
C                                                                       
      SUBROUTINE DRAGON(PHISA,ZLWFLAG,USLMF,VSLMF,TSURF,TG)             
                                                                        
      DIMENSION PHISA(IM,JM),ZLWFLAG(IM,JM),USLMF(IM,JM),VSLMF(IM,JM),  
     1          TSURF(IM,JM),TG(IM,JM)                                  
                                                                        
      COMMON/SFCDRAG/ DRAG(13104),IWATER(13104)                         
                                                                        
      COMMON /CONTRL/ IM,JNP,NB,NDALT,NHMS,NLAY,NLAYM1,NLAYP1,NYMD,     
     1                STRAT,IDIMEN,SLP,FDCOS,FEXP,SLT,SIGDAT,MAXREP     
                                                                        
      LOGICAL         STRAT,SLP,FDCOS,FEXP,SLT,SIGDAT                   
                                                                        
      EQUIVALENCE (JNP,JM)                                              
                                                                        
      COMMON /PHYSIC/ BETA,CP,GRAV,OMEGA2,RADE,RGAS,ROCP,CPOG,GAMMA,    
     1                ROCP1,GOCP                                        
                                                                        
      DATA ZERO      /0.0/                                              
      DATA ONE       /1.0/                                              
      DATA TWO       /2.0/                                              
      DATA FIVE      /5.0/                                              
      DATA SEVEN     /7.0/                                              
      DATA EIGHTEEN /18.0/                                              
      DATA HAFF      /0.5/                                              
      DATA TENM3    /.001/                                              
      DATA PT00125  /.00125/                                            
      DATA PT0025   /.0025/                                             
      DATA PT07      /.07/                                              
                                                                        
C---------------------------------------------------------------------- 
C---------------------------------------------------------------------- 
                                                                        
      K = 0                                                             
      DO 20 J=1,JM                                                      
      DO 20 I=1,IM                                                      
         K = K + 1                                                      
         IWATER(K) = ZLWFLAG(I,J)+0.001                                 
 20   CONTINUE                                                          
                                                                        
      PRINT 6020                                                        
 6020 FORMAT(' IWATER FLAG IN DRAGON:')                                 
      K=IM*JM                                                           
      DO 21 J=1,JM                                                      
         PRINT 6021, (IWATER(I),I=K-IM+1,K)                             
 6021    FORMAT(' ',72I1)                                               
         K=K-IM                                                         
   21 CONTINUE                                                          
                                                                        
      DO 50 J=1,JM                                                      
                                                                        
          JJ = (J-1)*IM                                                 
                                                                        
      DO 50 I=1,IM                                                      
                                                                        
          KK = JJ + I                                                   
                                                                        
C  TEMPERATURE DIFFERENCE BETWEEN GROUND AND SURFACE                    
C  -------------------------------------------------                    
                                                                        
          DELT = TG(I,J) - TSURF(I,J)                                   
                                                                        
                                                                        
C  WIND SPEED CALCULATIONS                                              
C  ----------------------                                               
                                                                        
          WIND = SQRT( USLMF(I,J) * USLMF(I,J) +                        
     1                  VSLMF(I,J) * VSLMF(I,J)  )                      
                                                                        
          IF(WIND .LT. TENM3) WIND = ZERO                               
                                                                        
C  CALCULATE DRAG COEFFICIENT CD                                        
C  -----------------------------                                        
                                                                        
          CD = (ONE + PT07*WIND) * TENM3                                
                                                                        
                                                                        
          IF(CD .LT. PT0025) THEN                                       
             CD = HAFF*CD                                               
          ELSE                                                          
             CD = PT00125                                               
          ENDIF                                                         
                                                                        
C  CALCULATE STABILITY-DEPENDENT AIR-SURFACE INTERACTION COEFFICIENT    
C  -----------------------------------------------------------------    
                                                                        
          IF(DELT .GE. ZERO) THEN                                       
                                                                        
             DRG = CD * (WIND + SQRT(DELT))                             
                                                                        
          ELSE                                                          
                                                                        
             DRG = CD * WIND*WIND*WIND / (WIND*WIND - SEVEN*DELT)       
                                                                        
          ENDIF                                                         
                                                                        
C FOR SEA LEVEL PRESSURE ANALYSIS, CALCULATE DRAG OVER OCEANS ONLY      
C ----------------------------------------------------------            
                                                                        
          IF(IWATER(KK) .EQ. 1) THEN                                    
                                                                        
             DRAG(KK) = EIGHTEEN*GRAV*DRG/(RGAS*TSURF(I,J))             
                                                                        
          ELSE                                                          
                                                                        
             DRAG(KK) = ZERO                                            
                                                                        
          ENDIF                                                         
                                                                        
 50   CONTINUE                                                          
                                                                        
      RETURN                                                            
      END                                                               
