/*
del_dt: Extract beginning and ending dates and times from DEL file.

Usage: del_dt  [ -s ]  del_file_name

Reads the OI "DEL" data set that contains the observation minus first guess
(O-F) values.  The first and last dates and times encountered in the file
on the subheaders are printed to standard output as YYMMDD HHMMSS YYMMDD HHMMSS,
unless the "-s" flag is set, in which case the dates and times are written as a 
time tag suffix: "bYYMMDDHH.eYYMMDDHH".  If an error is encountered, a message 
is printed to standard error only.  A date of "0" is considered an error; this
would be returned by a zero length file.

Options:

   -s          Write the begining and ending dates and times as a time tag
               suffix: "bYYMMDDHH.eYYMMDDHH".

The structure of the DEL data set is 

t=1,all_times
   nobs, nymd, nhms, 'SLP'   ! SLP subheader
   n=1,nobs
      SLP deltas (8 words/record)
   end do
   nobs, nymd, nhms, 'MIX'   ! MIX subheader
   n=1,nobs
      MIX deltas (8 words/record)
   end do
   nobs, nymd, nhms, 'ZUV'   ! ZUV subheader
   n=1,nobs
      ZUV deltas (8 words/record)
   end do
end do

Note that the DEL data set is written in 32 bit (4 byte) IEEE format with f77 
control words; this adds 4 bytes to the beginning and end of each record.  del_dt
works by reading a subheader and positioning the file position indicator to the 
start of the next subheader.

Return codes and actions:

   del_dt will only write to standard output if the read is successful.
   Error messages are written to standard error.

   0 - Successful.
   1 - Improper argument list.
   2 - Could not open file.
   3 - Error reading file.
*/

#include <stdio.h>
#include <stdlib.h>

int main(int argc, char *argv[]);
int rd_del_hdr(FILE *fp_del_file, int *nobs, int *nymd, int *nhms);
int skip_del(FILE *fp_del_file, int nobs);

int main(int argc, char *argv[]) {

   int nobs = 0;
   int nymd = 0;
   int nhms = 0;
   int ierr;
   int begin_date = 0;
   int begin_time = 0;
   int end_date = 0;
   int end_time = 0;
   int c;
   int suffix_tag = 0;
   char *del_file;
   extern char *optarg;
   extern int optind;

   FILE *fp_del_file;

/* Parse options and arguments */

   while ( (c = getopt(argc, argv, "s")) != -1 ) {

      switch (c) {
      case 's':
         suffix_tag=1;
         break;
      case '?':
         fprintf(stderr,"usage: del_dt  [ -s ]  del_file_name\n");
         return (1);
      }

   }

   if ( optind >= argc ) {
      fprintf(stderr,"usage: del_dt  [ -s ]  del_file_name\n");
      return (1);
   } else {
      del_file=argv[optind];
   }

   if ( (fp_del_file=fopen(del_file,"rb") ) == NULL ) {
      fprintf(stderr,"Can not open file: %s\n",del_file);
      return (2);
   } else {

      while ( ( ierr=rd_del_hdr(fp_del_file,&nobs,&nymd,&nhms) ) == 0 ) {


         if ( skip_del(fp_del_file,nobs) ) {
            fprintf(stderr,"Error reading file: %s\n",del_file);
            fclose(fp_del_file);
            return (3);
         }

         if ( begin_date == 0) {
            begin_date=nymd;
            begin_time=nhms;
         }

         end_date=nymd;
         end_time=nhms;

      }

      if ( ierr == 1 && begin_date != 0 ) {

         if ( suffix_tag ) {
            printf("b%.6d%.2d.e%.6d%.2d\n",begin_date,begin_time/10000,end_date,end_time/10000);
         } else {
            printf("%.6d %.6d %.6d %.6d\n",begin_date,begin_time,end_date,end_time);
         }
         fclose(fp_del_file);
         return (0);

      } else {

         fprintf(stderr,"Error reading file: %s\n",del_file);
         fclose(fp_del_file);
         return (3);

      } 

   }

}

int rd_del_hdr(FILE *fp_del_file, int *nobs, int *nymd, int *nhms) {

   int i;
   int n_bufr = 23;
   char hdr_bufr[23];
   union conv {
      int  int8;
      char char8[8];
   } ctoi;

   if ( fread(&hdr_bufr,1,n_bufr,fp_del_file) != n_bufr ) {

      if ( feof(fp_del_file) ) {
         return (1);
      } else if ( ferror(fp_del_file) ) {
         return (2);
      } else {
         return (3);
      }

   } else {

      ctoi.int8=0;
      for ( i=0 ; i<4 ; i ++ ) ctoi.char8[4+i]=hdr_bufr[4+i];
      *nobs=ctoi.int8;

      ctoi.int8=0;
      for ( i=0 ; i<4 ; i ++ ) ctoi.char8[4+i]=hdr_bufr[8+i];
      *nymd=ctoi.int8;

      ctoi.int8=0;
      for ( i=0 ; i<4 ; i ++ ) ctoi.char8[4+i]=hdr_bufr[12+i];
      *nhms=ctoi.int8;

      return (0);

   }

}

int skip_del(FILE *fp_del_file, int nobs) {

   long int nbskip;

/* Compute number of bytes to skip ( = obs.inobs records * 40 bytes/record */

   nbskip=nobs*40;

   if ( fseek(fp_del_file, nbskip, SEEK_CUR) ) {
      return (1);
   } else {
      return (0);
   }

}
