/* 
restart_dt: Extract date and time from Phoenix restart file.

Usage: restart_dt  [ -d ]  [ -s ]  restart_file_name

Reads first record of Phoenix GCM restart file, extracts date (nymd) and 
time (nhms) and writes date and time to standard output as YYMMDD HHMMSS. 
If the "-d" flag is set, however, only the date is written.  If the "-s" 
flag is set, then the date and time are written as a time tag suffix: 
"tYYMMDDHH".  The "-s" flag overrides the "-d" flag.

Options:

   -d          Write the date only.
   -s          Write the date and time as a time tag suffix: "tYYMMDDHH".

The contents of the first record in a restart file are 

   nymd, nhms, nb, nymd0, nhms0, imax, jmaxm1, kmax,               
   kprogs1, kprogu1, kprogs2, kprogu2,                             
   kphys, nlwcld, nswcld, job, ntype

Note that a control word will precede this record.

Return codes and actions:

   restart_dt will only write to standard output if the read is successful.
   Error messages are written to standard error.

   0 - Successful read; date written to standard output as YYMMDD.
   1 - Improper argument list.
   2 - Could not open file.
   3 - Error reading file.
*/

#include <stdio.h>
#include <stdlib.h>

int main(int argc, char *argv[]);

int main(int argc, char *argv[]) {

   int nymd;
   int nhms;
   int bufr[18];
   int n_bufr = 18;
   int c;
   int date_only = 0;
   int suffix_tag = 0;
   char *restart_file;
   extern char *optarg;
   extern int optind;

   FILE *fp_restart_file;

/* Parse options and arguments */

   while ( (c = getopt(argc, argv, "ds")) != -1 ) {

      switch (c) {
      case 'd':
         date_only=1;
         break;
      case 's':
         suffix_tag=1;
         break;
      case '?':
         fprintf(stderr,"usage: restart_dt  [ -d ]  [ -s ]  restart_file_name\n");
         return (1);
      }

   }

   if ( optind >= argc ) {
      fprintf(stderr,"usage: restart_dt  [ -d ]  [ -s ]  restart_file_name\n");
      return (1);
   } else {
      restart_file=argv[optind];
   }

   if ( (fp_restart_file=fopen(restart_file,"rb") ) == NULL ) {
      fprintf(stderr,"Can not open file: %s\n",restart_file);
      return (2);
   } else {

      if ( fread(&bufr,sizeof(int),n_bufr,fp_restart_file) != n_bufr ) {
         fprintf(stderr,"Error reading file: %s\n",restart_file);
         fclose(fp_restart_file);
         return (3);
      } else {

         if ( suffix_tag ) {
            printf("t%.6d%.2d\n",bufr[1],bufr[2]/10000);
         } else {

            if ( date_only ) {
               printf("%.6d\n",bufr[1]);
            } else {
               printf("%.6d %.6d\n",bufr[1],bufr[2]);
            }

         }

         fclose(fp_restart_file);
         return (0);

      }

   }

}
